@@ -15,7 +15,7 @@ our @EXPORT_OK = qw(
 );
 our %EXPORT_TAGS = ( 'all' => \@EXPORT_OK, );
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 sub pin_sha256 {
     my ($path) = @_;
@@ -47,7 +47,7 @@ HTTP::PublicKeyPins - Generate RFC 7469 HTTP Public Key Pin (HPKP) header values
 
 =head1 VERSION
 
-Version 0.02
+Version 0.03
 
 =head1 SYNOPSIS
 
@@ -69,7 +69,7 @@ Make it more difficult for the bad guys to Man-In-The-Middle your users TLS sess
 
 OR 
 
-    perl -MHTTP::PublicKeyPins=pin_sha256 -e 'print pin_sha256("example.pem") . "\n";'
+    perl -MHTTP::PublicKeyPins=pin_sha256 -e 'print pin_sha256("/etc/pki/tls/certs/example.pem") . "\n";'
 
 =head1 DESCRIPTION
 
@@ -107,7 +107,7 @@ None known.
 
 =head1 SEE ALSO
 
- L<http://tools.ietf.org/html/rfc7469>
+L<RFC 7469 - Public Key Pinning Extension for HTTP|http://tools.ietf.org/html/rfc7469>
 
 =head1 AUTHOR
 
